There is a map with a fixed capacity and integers as keys.
For example, here is a map with a few keys can be created:
use emap::Map;
let mut m : Map<&str, 10> = Map::new();
m.insert(0, "Hello, world!");
m.insert(1, "Good bye!");
assert_eq!(2, m.len());Creating a Map requires knowing the maximum size of it upfront. This is
what the second type argument 10 is for, in the example above. The map
will have exactly ten elements. An attempt to add an 11th element will lead
to a panic.